#
# spec file for package acroread
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           acroread
BuildRequires:  ed openldap2-client update-desktop-files xorg-x11-devel
%if %suse_version < 1030
BuildRequires:  libicu
%endif
%if %suse_version > 1020
BuildRequires:  fdupes libcurl4
%endif
Url:            http://www.adobe.com/products/acrobat/readermain.html
License:        NON-OSI-COMPLIANT(royalties)
Group:          Productivity/Publishing/PDF
Provides:       linux-ar
%if %suse_version < 1030
Requires:       libcrypto.so.0.9.7 libssl.so.0.9.7 libcurl.so.3 libgcc_s.so.1  libstdc++.so.6 libicudata.so.34 libicui18n.so.34 libicuuc.so.34
%elseif %suse_version >= 1030
Requires:       libcrypto.so.0.9.8 libssl.so.0.9.8 libcurl.so.4 libgcc_s.so.1  libstdc++.so.6
%endif
AutoReqProv:    on
Requires:       UTF-16.so ISO8859-1.so
Summary:        Adobe Reader for PDF Files
Source10:       acroread.desktop
Source20:       acroread.png
Source30:       suse-do-not-grab-server.tar.bz2
Source40:       acroread.patch
Source50:       acroread-rpmlintrc
Patch0:         install.patch
# this Version is reported when calling "acroread -version"
Version:        9.5.1
Release:        0.7.1
Source0:        ftp://ftp.adobe.com/pub/adobe/reader/unix/9.x/%{version}/enu/AdbeRdr%{version}-1_i486linux_enu.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       openldap2-client coreutils
NoSource:       0
ExclusiveArch:  %ix86

%description
Acroread is a well known PDF viewer.

Adobe Reader is often the only program able to process complicated PDF
files, such as PDF forms. However, there are many bugs where we cannot
do anything about because it is proprietary binary-only software.

Please consider whether it is possible to use free PDF readers like
okular, evince, xpdf, ghostview, ... instead.



Authors:
--------
    Adobe Systems Incorporated

%define my_provides /tmp/my-provides
%define my_requires /tmp/my-requires
%define INSTALL_DIR /usr/lib
%define _use_internal_dependency_generator 0

%prep
# unpack the Source into a suitable directory
# there is the top-level directory "AdobeReader" in the source archive
%setup -n AdobeReader
# apply Patch0 to skip the "OutputLicense" dialog in the INSTALL script
%patch0
# retrieve the gif for desktop
tar -xvf COMMON.TAR Adobe/Reader9/Resource/Icons/128x128/AdobeReader9.png
tar -xvf COMMON.TAR Adobe/Reader9/Resource/Shell/acroread.1.gz

%build
# there is nothing to build as this package is a binary-only package
# but we build a preload library to work around bug #375551:
tar xf %{S:30}
make -C suse-do-not-grab-server

%install
# skip the automated stripping because this damages some functionality
# for example a stripped AcroForm.api can no longer fill in forms
# see bug 28717 for details
export NO_BRP_STRIP_DEBUG="true"
# stuff to be done before the installation
# do the installation
./INSTALL <<EOT
%{buildroot}%INSTALL_DIR
y
EOT
# stuff to be done after the installation
rm -rf %{buildroot}%INSTALL_DIR/Adobe/Reader9/bin/UNINSTALL
# set the correct install_dir in the "acroread" start script
# to be safe to note changes in new versions do a test before
grep -q '^install_dir=' %{buildroot}%INSTALL_DIR/Adobe/Reader9/bin/acroread || exit 1
sed -i -e 's:^install_dir=.*$:install_dir="/usr/lib/Adobe/Reader9/Reader":' %{buildroot}%INSTALL_DIR/Adobe/Reader9/bin/acroread
# Apply workaround for http://bugzilla.novell.com/show_bug.cgi?id=85416 & 147966 & 275088:
pushd %{buildroot}%INSTALL_DIR/Adobe/Reader9/bin
    patch -p0 -i %{S:40}
popd
# symlink the executable to a directory which is in the PATH
mkdir -p %{buildroot}/usr/bin
pushd %{buildroot}/usr/bin
   ln -sf ../../%INSTALL_DIR/Adobe/Reader9/bin/acroread acroread
popd
# add a link for the browser plugin so that it can be found automatically
mkdir -p %{buildroot}/usr/lib/browser-plugins
ln -sf %INSTALL_DIR/Adobe/Reader9/Browser/intellinux/nppdf.so %{buildroot}/usr/lib/browser-plugins/nppdf.so
# Add links to openldap2 libraries needed to avoid bug: 261555
%if %suse_version > 1030
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libldap-2.4.so.? libldap.so)
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/liblber-2.4.so.? liblber.so)
%else
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libldap-2.3.so.? libldap.so)
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/liblber-2.3.so.? liblber.so)
%endif
for i in Adobe/Reader9/Reader/GlobalPrefs/.config \
         Adobe/Reader9/Resource/Support/AdobeReader.desktop
do
    sed -i -e 's:%{buildroot}::' %{buildroot}%INSTALL_DIR/$i
done
# make the Adobe Reader available in the SUSE menues
%suse_update_desktop_file -i %name Office Viewer
echo "InitialPreference=7" >> %{buildroot}/usr/share/applications/%name.desktop
# install preload library to work around bug #375551:
install -m 755 suse-do-not-grab-server/suse-do-not-grab-server.so \
    %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib
# remove duplicated system libraries and massage provides and requires lists:
#
# When a compatible version of a library which comes with the acroread
# binary tarball is already available in the system, it should be deleted.
# See bnc#353251.
# Libraries which come with the acroread tarball where no compatible
# version is available in the system cannot be deleted but they
# should neither be provided nor required by acroread.
# Providing them might cause problems for other packages which
# might require these libraries and requiring them is not necessary
# because they are already within the acroread package).
%if %suse_version < 1030
rm -f %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib/lib{crypto,ssl,curl,gcc_s,stdc++,icudata,icui18n,icuuc}.so*
# bnc#373590:
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libicudata.so.34 libicudata.so)
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libicui18n.so.34 libicui18n.so)
(cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libicuuc.so.34 libicuuc.so)
cat << EOF > %{my_provides}
%{__find_provides} | grep -vE "liblber|libldap" ; exit 0
EOF
chmod 755 %{my_provides}
%define __find_provides %{my_provides}
cat << EOF > %{my_requires}
%{__find_requires} | grep -vE "liblber|libldap" ; exit 0
EOF
chmod 755 %{my_requires}
%define __find_requires %{my_requires}
%elseif %suse_version >= 1030
rm -f %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib/lib{crypto,ssl,gcc_s,stdc++}.so*
# apparently libcurl.so.4 and libcurl.so.3 are *not* compatible, see bnc#382777.
# # libcurl.so.4 and libcurl.so.3 are supposedly compatible, see bnc#353251 comment #29:
# (cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libcurl.so.4 libcurl.so)
# (cd %{buildroot}%INSTALL_DIR/Adobe/Reader9/Reader/intellinux/lib && ln -sf ../../../../../../../usr/lib/libcurl.so.4 libcurl.so.3)
cat << EOF > %{my_provides}
%{__find_provides} | grep -vE "libicudata|libicui18n|libicuuc|liblber|libldap|libcurl.so.3" ; exit 0
EOF
chmod 755 %{my_provides}
%define __find_provides %{my_provides}
cat << EOF > %{my_requires}
%{__find_requires} | grep -vE "libicudata|libicui18n|libicuuc|liblber|libldap|libcurl.so.3" ; exit 0
EOF
chmod 755 %{my_requires}
%define __find_requires %{my_requires}
%endif
# install the acroread icon for desktop
install -d %{buildroot}/usr/share/pixmaps
install -m644 Adobe/Reader9/Resource/Icons/128x128/AdobeReader9.png %{buildroot}/usr/share/pixmaps/acroread.png
# install the manunal, bnc#631267, bili@novell.com
install -d %{buildroot}/usr/share/man/man1
install -m644 Adobe/Reader9/Resource/Shell/acroread.1.gz %{buildroot}/usr/share/man/man1/
# libsccore.so and libextendscript.so have RPATH=. which is not good.
# But we cannot change this in a binary only package, we can only
# disable the check:
export NO_BRP_CHECK_RPATH=true
%if %suse_version > 1020
%fdupes %{buildroot}%INSTALL_DIR
%endif

%post 
/usr/bin/touch -c %_libdir/browser-plugins/libdragonegg.so

%postun 
/usr/bin/touch -c %_libdir/browser-plugins/libdragonegg.so

%clean
rm -f %{my_provides}
rm -f %{my_requires}

%files 
%defattr(-,root,root)
%doc ReadMe.htm
/usr/share/pixmaps/acroread.png
/usr/share/man/man1/acroread.1.gz
/usr/bin/acroread
/usr/lib/browser-plugins/nppdf.so
/usr/share/applications/%name.desktop
%dir %INSTALL_DIR/Adobe/
%dir %INSTALL_DIR/Adobe/Reader9
%dir %INSTALL_DIR/Adobe/Reader9/Browser/
%INSTALL_DIR/Adobe/Reader9/Browser/*
%dir %INSTALL_DIR/Adobe/Reader9/Reader/
%INSTALL_DIR/Adobe/Reader9/Reader/*
%dir %INSTALL_DIR/Adobe/Reader9/bin/
%INSTALL_DIR/Adobe/Reader9/bin/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/
%dir %INSTALL_DIR/Adobe/Reader9/Resource/CMap/
%INSTALL_DIR/Adobe/Reader9/Resource/CMap/Identity*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/Font/
%INSTALL_DIR/Adobe/Reader9/Resource/Font/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/Icons/
%INSTALL_DIR/Adobe/Reader9/Resource/Icons/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/Linguistics/
%INSTALL_DIR/Adobe/Reader9/Resource/Linguistics/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/Support/
%INSTALL_DIR/Adobe/Reader9/Resource/Support/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/TypeSupport/
%dir %INSTALL_DIR/Adobe/Reader9/Resource/TypeSupport/Unicode
%INSTALL_DIR/Adobe/Reader9/Resource/TypeSupport/Unicode/*
%dir %INSTALL_DIR/Adobe/Reader9/Resource/Shell
%INSTALL_DIR/Adobe/Reader9/Resource/Shell/*

%changelog
* Fri Apr 13 2012 bili@suse.com
- Update to 9.5.1 for bnc#756574(swampid#46644).
  CVE-2012-0774, CVE-2012-0775, CVE-2012-0777
* Wed Jan 11 2012 bili@suse.com
- Update to 9.4.7 for bnc#735275(swampid#44853).
  CVE-2011-4369
* Fri Nov 11 2011 bili@suse.com
- Update to 9.4.6 for bnc#717724(swampid#44054).
  CVE-2011-1353, CVE-2011-2431, CVE-2011-2432, CVE-2011-2433,
  CVE-2011-2434, CVE-2011-2435, CVE-2011-2436, CVE-2011-2437,
  CVE-2011-2438, CVE-2011-2439, CVE-2011-2440, CVE-2011-2441,
  CVE-2011-2442
* Mon Feb 28 2011 bili@novell.com
- Update to 9.4.2 for bnc#669550 (swampid#38967).
  CVE Numbers: CVE-2010-4091, CVE-2011-0562, CVE-2011-0563, CVE-2011-0564,
  CVE-2011-0565, CVE-2011-0566, CVE-2011-0567, CVE-2011-0568, CVE-2011-0570,
  CVE-2011-0585, CVE-2011-0586, CVE-2011-0587, CVE-2011-0588, CVE-2011-0589,
  CVE-2011-0590, CVE-2011-0591, CVE-2011-0592, CVE-2011-0593, CVE-2011-0594,
  CVE-2011-0595, CVE-2011-0596, CVE-2011-0598, CVE-2011-0599, CVE-2011-0600,
  CVE-2011-0602, CVE-2011-0603, CVE-2011-0604, CVE-2011-0605, CVE-2011-0606
* Fri Dec  3 2010 bili@novell.com
- Update to 9.4.1 for bnc#651232 (swampid#37028).
  Fix a memory corruption vulnerability that could potentially
  lead to code execution (CVE-2010-4091).
* Wed Oct  6 2010 mrdocs@opensuse.org
- Update to 9.4 for security fixes bnc#638466 swampid#36257
- CVE-2010-2883 CVE-2010-2884 CVE-2010-2887 CVE-2010-2888
- CVE-2010-2889 CVE-2010-2890 CVE-2010-3619 CVE-2010-3620
- CVE-2010-3621 CVE-2010-3622 CVE-2010-3623 CVE-2010-3624
- CVE-2010-3625 CVE-2010-3626 CVE-2010-3627 CVE-2010-3628
- CVE-2010-3629 CVE-2010-3630 CVE-2010-3631 CVE-2010-3632
- CVE-2010-3658 CVE-2010-3656 CVE-2010-3657
* Thu Aug 26 2010 bili@novell.com
- Update to 9.3.4 for integer overflow(bnc#629134, swampid#35325).
  CVE-2010-2862, CVE-2010-1240.
- Dismiss many nasty symlink messages(bnc#627964).
- Add the manual for acroread(bnc#631267).
- Fix prints dirname error upon start(bnc#574580).
* Thu Jul  1 2010 bili@suse.de
- Update to 9.3.3 for security fixes(bnc#612064, swampid#34217).
  CVE-2010-1297, CVE-2010-1240, CVE-2010-1285, CVE-2010-1295,
  CVE-2010-2168, CVE-2010-2201, CVE-2010-2202, CVE-2010-2203,
  CVE-2010-2204, CVE-2010-2205, CVE-2010-2206, CVE-2010-2207,
  CVE-2010-2208, CVE-2010-2209, CVE-2010-2210, CVE-2010-2211,
  CVE-2010-2212.
* Mon Apr 19 2010 bili@suse.de
- Update to 9.3.2 for security fixes(bnc#595108, swampid#32589).
  CVE-2010-0190, CVE-2010-0191, CVE-2010-0192, CVE-2010-0193,
  CVE-2010-0194, CVE-2010-0195, CVE-2010-0196, CVE-2010-0197,
  CVE-2010-0198, CVE-2010-0199, CVE-2010-0201, CVE-2010-0202,
  CVE-2010-0203, CVE-2010-0204, CVE-2010-1241
* Fri Jan 22 2010 bili@suse.de
- Update to 9.3 for security fixes(bnc#564742, swampid#29655).
  CVE-2009-3953, CVE-2009-3954, CVE-2009-3955, CVE-2009-3956,
  CVE-2009-3957, CVE-2009-3958, CVE-2009-3959, CVE-2009-4324
* Mon Oct 19 2009 pth@suse.de
- Update to 9.2 because of security fixes (bnc#546083)
* Wed Sep  2 2009 pth@suse.de
- Add a Source: entry for the rpmlintrc file.
* Thu Aug 27 2009 pth@suse.de
- Update to 9.1.3
- Add an rpmlintrc file
- Don't list acroread.patch as a patch but rather as Source: so
  that rpmlint won't complain.
* Tue May 19 2009 crrodriguez@suse.de
- VUL-0: acroread: Adobe Reader 'getAnnots()'
  Javascript Function Remote Code Execution [bnc#499097]
* Wed Mar 25 2009 crrodriguez@suse.de
- VUL-0: acroread security update [bnc#488619]
* Mon Jan 19 2009 mfabian@suse.de
- bnc#457928: add the workaround to copy the xulrunner-1.9
  directory to the home directory of the user if libgtkembedmoz.so
  is not available (see comment#24 of bnc#457928).
* Mon Jan 19 2009 mfabian@suse.de
- bnc#467195: require UTF-16.so and ISO8859-1.so in order to
  get the package glibc-locale-32bit required when acroead is
  installed on a 64bit system.
* Thu Dec 11 2008 hvogel@suse.de
- bnc#457928: temporarily get rid of the libgtkembedmoz.so
  requirement. xulrunner-181 got dropped
* Wed Nov  5 2008 mfabian@suse.de
- bnc#441739, bnc#397839: update to 8.1.3 for security reasons:
  http://www.adobe.com/support/security/bulletins/apsb08-19.html
  CVE-2008-2992, CVE-2008-2549, CVE-2008-4812, CVE-2008-4813,
  CVE-2008-4817, CVE-2008-4816, CVE-2008-4814, CVE-2008-4815
* Wed Aug 13 2008 ro@suse.de
- add exclusivearch
* Mon Jul 21 2008 mfabian@suse.de
- bnc#404976: security update, CVS-2008-2641.
- remove hunks to use mktemp from acroread.patch, the problem
  has been fixed upstream now, mktemp is used if available.
* Mon Apr 28 2008 mfabian@suse.de
- bnc#382739: use more robust code in the startscript to find
  libgtkembedmoz.so. Only use the value found in ~/.adobe/
  if it really points to a libgtkembedmoz.so, if not search
  anew in the system.
* Wed Apr 23 2008 mfabian@suse.de
- bnc#382777: do not replace the libcurl.so.3.0.0 which comes
  with the acroread tarball with symbolic links to
  libcurl.so.4.0.0 in the system, apparently these are *not*
  compatible.
* Fri Apr  4 2008 mfabian@suse.de
- bnc#375551: use LD_PRELOAD to prevent acroread from using
  XGrabServer and XUngrabServer.
- bnc#373590: add symlinks to libicu*.so.34 for suse_version
  < 1030 where libicu* has been deleted from the acroread package.
* Mon Mar 17 2008 mfabian@suse.de
- bnc#370330 and bnc#353251: add a workaround to the start script
  /usr/bin/acroread to make input via XIM work when acroread
  is started in an UTF-8 locale (.UTF-8 is cut off from the
  locale name then to “fix” the problem).
* Wed Feb 20 2008 mfabian@suse.de
- bnc#362926: use "mktemp" to create temporary files in a secure
  way.
- detect the correct directory for the 32bit libgtkembedmoz.so on
  x86_64 systems.
* Wed Feb 20 2008 mfabian@suse.de
- bnc#353251: remove duplicated system libraries (because of
  security considerations and compatibility problems).
* Thu Feb 14 2008 mfabian@suse.de
- bnc#358438 comment #31-#33: Workaround to make acroread start
  when XInputExtension is missing on an X-server (this is missing
  on VNC X-servers) and the theme package gtk-qt-engine is
  installed.
* Thu Feb  7 2008 mfabian@suse.de
- bnc#275088, commment #134-#139: set ACRO_ENABLE_FONT_CONFIG=1
  in the acroread start script.
* Tue Feb  5 2008 mfabian@suse.de
- update to final release of 8.1.2.
  Fixes bnc#358438, bnc#275088, bnc#353927.
  Official announcement by Adobe is here:
  http://blogs.adobe.com/acroread/2008/02/adobe_reader_812_for_linux_and.html
  “Version 8.1.2 contains scores of bug fixes including security
  vulnerability fixes.”
* Fri Jan 11 2008 mfabian@suse.de
- use fdupes only for openSUSE >= 10.3.
* Fri Jan 11 2008 mfabian@suse.de
- update to 8.1.2 (fixes bugzilla #275088).
* Tue Nov 20 2007 mfabian@suse.de
- apply patch to start script again to use XIM and to add the
  most important directories to PSRESOURCEPATH.
- use fdupes only in %%INSTALL_DIR (/usr/lib) to avoid hardlinks
  to /usr/share which might be on a different partition.
* Tue Oct 16 2007 mfabian@suse.de
- add "Requires: libgtkembedmoz.so".
* Mon Oct  8 2007 mfabian@suse.de
- update to 8.1.1.
- fix automatic provides and requires.
- use fdupes.
* Fri Aug 31 2007 mfabian@suse.de
- Bugzilla #275088: add important font directories to the default
  PSRESOURCEPATH.
* Thu Jul  5 2007 coolo@suse.de
- adding desktop file and icon to the package instead of relying
  on kde's pool
* Thu Apr 12 2007 ghorlacher@novell.com
- Added BuildRequires: openldap2-client for mbuild to work.
* Thu Apr 12 2007 ghorlacher@novell.com
- Updated patch to acroread script for bug #197929.
  Added Requires: openldap2-client and created symbolic links for
  libldap and liblber to avoid error 'PPKLite.api' Bug #261555.
* Thu Feb  1 2007 ghorlacher@suse.de
- Bug 234534 - acroread doesn't work after last factory upgrade
  Added patch suggested in Bug.
* Wed Jan 24 2007 ro@suse.de
- move from /usr/X11R6 to /usr
* Sat Jan 20 2007 ghorlacher@suse.de
- Updated acroread.patch for bug: 197929 - acroread: line 493:
  [: -ge: unary operator expected.
* Wed Jan 17 2007 ghorlacher@novell.com
- Updated to security patch 7.0.9 from Adobe. Readme.htm and help/
  about reader still show 7.0.8 - varified from Adobe that they
  did not update the revision for this release internally.
* Tue Jun 27 2006 ghorlacher@suse.de
- Put fix in for error message to stdout (#182376)
* Mon Jun 19 2006 ghorlacher@novell.com
- Updated to 7.0.8 from Adobe for security fixes (#185936)
* Wed Mar 29 2006 dmueller@suse.de
- touch dragonegg plugin, so that mozilla refreshes its cache (#155318)
* Fri Mar 17 2006 ghorlacher@suse.de
- Added acroread.patch for Bugfix: 147966 and 85416 in startup
  script. Removed bugzilla-85416.patch (included in new patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan  6 2006 ghorlacher@novell.com
- New version - 7.0.5 from Adobe, updated patches to work with
  new files recieved.
* Thu Aug 18 2005 ghorlacher@suse.de
- Updated the spec file to reflect new version number. 7.0.1
* Thu Aug 18 2005 ghorlacher@suse.de
- Updating to version 7.0.1 for security issue. bug 105054
* Wed Aug 17 2005 mfabian@suse.de
- Bugzilla #85416: add workaround to avoid crash when scim is
  installed (add "export GTK_IM_MODULE=xim" to the start skript).
* Tue Jul 12 2005 ghorlacher@suse.de
- Added NoSource: 0 back in to spec file
* Mon Jul 11 2005 ghorlacher@suse.de
- Updating the changelog to reflect the history better
* Thu Jul  7 2005 ghorlacher@suse.de
- Updating 9.1 9.2 sles9 with version 7 for bug 95350 - security issue
* Thu Jun 23 2005 ghorlacher@suse.de
- Added back acroread.png extracting the gif from their COMMON.TAR
  file and then installing it to usr/share/pixmaps
* Tue Apr 26 2005 ro@suse.de
- use NoSource
* Thu Apr 21 2005 ghorlacher@suse.de
- Updated to Adobe reader 7.0.0 Gold Master
* Fri Apr  8 2005 ghorlacher@suse.de
- Removed /usr/share/pixmaps/acroread.png from install section for NLD
  Which does not have the suse_update_desktop_file setup for this.
* Wed Mar 30 2005 jsmeix@suse.de
- Added "norootforbuild".
* Wed Mar 16 2005 ro@suse.de
- block provides and requires for internal-only copies of
  system libraries
* Wed Mar 16 2005 jsmeix@suse.de
- Updated to Adobe Reader 7.0.0 RC1
* Thu Dec 16 2004 jsmeix@suse.de
- Update to version 5.010 which has a security fix that solves
  a problem with malformed mail containing pdf attachments
  (see SUSE bugzilla bug #49257).
* Wed Nov 17 2004 jsmeix@suse.de
- included the icon /usr/share/pixmaps/acroread.png
  which is installed by %%suse_update_desktop_file
* Wed Aug  4 2004 jsmeix@suse.de
- Update to version 5.09
* Sun Sep  7 2003 adrian@suse.de
- raise priority of acroread on pdf files
* Thu Sep  4 2003 mfabian@suse.de
- unset LC_ALL in start script because Acroread still dumped
  core when LC_ALL was set to an UTF-8 locale
  (see also Bugzilla #28718).
* Mon Aug 18 2003 jsmeix@suse.de
- Add preun section because of the following reason:
  If Acrobat Reader is run by root then a file ...Font/AdobeFnt*
  is created. This file contains the actual font list of Acrobat
  Reader's fonts. As the actual hostname becomes part of the
  filename it must be deleted by using a wildcard.
* Mon Aug 18 2003 ro@suse.de
- export NO_BRP_STRIP_DEBUG
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Mon Aug 11 2003 jsmeix@suse.de
- Removed install_dir.patch because it is version dependend
  as RPM_BUILD_ROOT has the version included.
  Now it is done by in-place changing (using "perl -pi ...")
  $RPM_BUILD_ROOT/usr/X11R6/bin/acroread
* Mon Aug 11 2003 jsmeix@suse.de
- Security update to version 5.08 from
  ftp://ftp.adobe.com/pub/adobe/acrobatreader/unix/5.x/linux-508.tar.gz
  Reason:
  A security patch was applied that solves a problem reported
  with long URLs in weblinks which can cause a buffer overrun.
  See
  http://www.heise.de/security/news/meldung/38468
  and
  bugzilla.suse.de bug number 27666
* Tue Aug  5 2003 mfabian@suse.de
- use LC_CTYPE=POSIX, otherwise acroread will dump core when
  started with LC_CTYPE set to an UTF-8 locale, for example:
  "LANG=en_US.UTF-8 LC_CTYPE=ja_JP.UTF-8 acroread"
* Thu Jun 26 2003 ro@suse.de
- mention install_dir.patch  as patch in specfile
- don't use literal RPM_SOURCE_DIR in specfile
* Thu Jun 26 2003 jsmeix@suse.de
- added install_dir.patch because "use BuildRoot" sets
  RPM_BUILD_ROOT=/var/tmp/acroread-5.07-build
  which leads to the wrong install_dir setting.
* Tue Jun 24 2003 jsmeix@suse.de
- Security update to version 5.0.7 from
  http://download.adobe.com/pub/adobe/acrobatreader/unix/5.x/linux-507.tar.gz
  Reason:
  It was possible to execute shell commands which are included
  in links in PDF files because the reader executes in this case
  "sh -c <program> <embedded link>" - see
  http://www.heise.de/newsticker/data/dab-16.06.03-000/
* Tue Jun  3 2003 coolo@suse.de
- use BuildRoot
* Mon Feb 24 2003 ro@suse.de
- move plugin link to /usr/lib/browser-plugins
* Mon Aug 19 2002 tsieden@suse.de
- security update to version 5.06
* Tue Jun 11 2002 tsieden@suse.de
- update to version 5.05, cleanup spec file
* Tue Mar 19 2002 ro@suse.de
- added symlink in /opt/netscape/plugins
* Thu Dec  6 2001 mfabian@suse.de
- use LC_NUMERIC=POSIX to make really sure that buildtin fonts
  are found.
* Sat Dec  9 2000 nashif@suse.de
- sorted group
* Tue May  9 2000 ro@suse.de
- use english LANG for acroread to make it find builtin fonts
* Wed Mar 29 2000 ro@suse.de
- fixed access rights for documentation (#2637)
* Thu Feb 24 2000 freitag@suse.de
- update to version 4.05, nppdf insert again, works with Netscape
* Fri Jan 14 2000 ro@suse.de
- removed nppdf.so until we finally get a glibc-based version
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sat Aug 21 1999 bs@suse.de
- added Check
* Fri Aug 20 1999 uli@suse.de
- fixed Netscape paths
* Tue Jun 22 1999 uli@suse.de
- update -> 4.0
* Thu Jan  7 1999 uli@suse.de
- update 3.01 -> 3.02
- now makes use of Adobe-supplied install script
* Tue Nov 11 1997 ro@suse.de
- new version 3.01
  installs under /usr/X11R6/lib/Acrobat3
  start script in /usr/X11R6/bin/acroread
